@@ -1,24 +1,20 @@
 use strict;
 use warnings;
-
-package Test::CleanNamespaces; # git description: v0.16-4-g2259488
+package Test::CleanNamespaces; # git description: v0.18-17-g105d63a
 # ABSTRACT: Check for uncleaned imports
 # KEYWORDS: testing namespaces clean dirty imports exports subroutines methods
-$Test::CleanNamespaces::VERSION = '0.17';
-use Module::Runtime qw(require_module module_notional_filename);
-use Sub::Identify qw(sub_fullname stash_name);
+
+our $VERSION = '0.19';
+
+use Module::Runtime ();
+use Sub::Identify ();
 use Package::Stash 0.14;
 use Test::Builder;
-use File::Find::Rule;
-use File::Find::Rule::Perl;
-use File::Spec::Functions 'splitdir';
-use namespace::clean;
+use File::Find ();
+use File::Spec;
 
-use Sub::Exporter -setup => {
-    exports => [
-        namespaces_clean     => \&build_namespaces_clean,
-        all_namespaces_clean => \&build_all_namespaces_clean,
-    ],
+use Sub::Exporter::Progressive -setup => {
+    exports => [ qw(namespaces_clean all_namespaces_clean) ],
     groups => {
         default => [qw/namespaces_clean all_namespaces_clean/],
     },
@@ -70,31 +66,31 @@ use Sub::Exporter -setup => {
 #pod
 #pod =cut
 
-sub build_namespaces_clean {
-    my ($class, $name) = @_;
-    return sub {
-        my (@namespaces) = @_;
-        local $@;
+sub namespaces_clean {
+    my (@namespaces) = @_;
+    local $@;
+    my $builder = builder();
 
-        my $result = 1;
-        for my $ns (@namespaces) {
-            unless (eval { require_module($ns); 1 }) {
-                $class->builder->skip("failed to load ${ns}: $@");
-                next;
-            }
-
-            my $imports = _remaining_imports($ns);
-
-            my $ok = $class->builder->ok(!keys(%$imports), "${ns} contains no imported functions");
-            $ok or $class->builder->diag($class->builder->explain('remaining imports: ' => $imports));
-
-            $result &&= $ok;
+    my $result = 1;
+    for my $ns (@namespaces) {
+        unless (eval { Module::Runtime::require_module($ns); 1 }) {
+            $builder->skip("failed to load ${ns}: $@");
+            next;
         }
 
-        return $result;
-    };
+        my $imports = _remaining_imports($ns);
+
+        my $ok = $builder->ok(!keys(%$imports), "${ns} contains no imported functions");
+        $ok or $builder->diag($builder->explain('remaining imports: ' => $imports));
+
+        $result &&= $ok;
+    }
+
+    return $result;
 }
 
+sub build_namespaces_clean { \&namespaces_clean }
+
 #pod =head2 build_all_namespaces_clean
 #pod
 #pod     my $coderef = Test::CleanNamespaces->build_all_namespaces_clean;
@@ -106,16 +102,14 @@ sub build_namespaces_clean {
 #pod
 #pod =cut
 
-sub build_all_namespaces_clean {
-    my ($class, $name) = @_;
-    my $namespaces_clean = $class->build_namespaces_clean();
-    return sub {
-        my @modules = $class->find_modules(@_);
-        $class->builder->plan(tests => scalar @modules);
-        $namespaces_clean->(@modules);
-    };
+sub all_namespaces_clean {
+    my @modules = find_modules(@_);
+    builder()->plan(tests => scalar @modules);
+    namespaces_clean(@modules);
 }
 
+sub build_all_namespaces_clean { \&all_namespaces_clean }
+
 # given a package name, returns a hashref of all remaining imports
 sub _remaining_imports {
     my $ns = shift;
@@ -124,7 +118,7 @@ sub _remaining_imports {
     my @imports;
 
     my $meta;
-    if ($INC{ module_notional_filename('Class::MOP') }
+    if ($INC{ Module::Runtime::module_notional_filename('Class::MOP') }
         and $meta = Class::MOP::class_of($ns)
         and $meta->can('get_method_list'))
     {
@@ -132,7 +126,7 @@ sub _remaining_imports {
         delete @subs{ $meta->get_method_list };
         @imports = keys %subs;
     }
-    elsif ($INC{ module_notional_filename('Mouse::Util') }
+    elsif ($INC{ Module::Runtime::module_notional_filename('Mouse::Util') }
         and Mouse::Util->can('class_of') and $meta = Mouse::Util::class_of($ns))
     {
         warn 'Mouse class detected - chance of false negatives is high!';
@@ -145,14 +139,14 @@ sub _remaining_imports {
     else
     {
         @imports = grep {
-            my $stash = stash_name($symbols->{$_});
+            my $stash = Sub::Identify::stash_name($symbols->{$_});
             $stash ne $ns
                 and $stash ne 'Role::Tiny'
                 and not eval { require Role::Tiny; Role::Tiny->is_role($stash) }
         } keys %$symbols;
     }
 
-    my %imports; @imports{@imports} = map { sub_fullname($symbols->{$_}) } @imports;
+    my %imports; @imports{@imports} = map { Sub::Identify::sub_fullname($symbols->{$_}) } @imports;
 
     # these subs are special-cased - they are often provided by other
     # modules, but cannot be wrapped with Sub::Name as the call stack
@@ -181,14 +175,19 @@ sub _remaining_imports {
 #pod =cut
 
 sub find_modules {
-    my ($class) = @_;
-    my @modules = map {
-        /^blib/
-            ? s/^blib.(?:lib|arch).//
-            : s/^lib.//;
-        s/\.pm$//;
-        join '::' => splitdir($_);
-    } File::Find::Rule->perl_module->in(-e 'blib' ? 'blib' : 'lib');
+    my @modules;
+    for my $top (-e 'blib' ? ('blib/lib', 'blib/arch') : 'lib') {
+        File::Find::find({
+            no_chdir => 1,
+            wanted => sub {
+                my $file = $_;
+                return
+                    unless $file =~ s/\.pm$//;
+                $file = File::Spec->abs2rel($file, $top);
+                push @modules, join '::' => File::Spec->splitdir($_);
+            },
+        }, $top);
+    }
     return @modules;
 }
 
@@ -219,7 +218,7 @@ Test::CleanNamespaces - Check for uncleaned imports
 
 =head1 VERSION
 
-version 0.17
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -337,21 +336,42 @@ L<Dist::Zilla::Plugin::Test::CleanNamespaces>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Test-CleanNamespaces>
+(or L<bug-Test-CleanNamespaces@rt.cpan.org|mailto:bug-Test-CleanNamespaces@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/perl-qa.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#perl> on C<irc.perl.org>|irc://irc.perl.org/#perl-qa>.
+
 =head1 AUTHOR
 
 Florian Ragwitz <rafl@debian.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Graham Knop
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 CONTRIBUTOR
-
-=for stopwords Karen Etheridge
-
-Karen Etheridge <ether@cpan.org>
-
 =cut
